@@ -271,15 +271,15 @@ static void cb_info_window(GtkWidget *widget, gpointer data, guint action) {
   struct info_row_t rows[] = {
     { "Sound input device:", strdup(session->audio_device_name_in)},
     { "Input speed:", ltostr(session->audio_speed_in) },
-    { "Input sample size:", ltostr(session->audio_sample_size_in * 8) },
+    { "Input sample size (bits):", ltostr(session->audio_sample_size_in * 8)},
     { "Input channels:", ltostr(1) },
     { "Sound output device:", strdup(session->audio_device_name_out)},
     { "Output speed:", ltostr(session->audio_speed_out) },
-    { "Output sample size:", ltostr(session->audio_sample_size_out * 8) },
+    { "Output sample size (bits):", ltostr(session->audio_sample_size_out*8)},
     { "Output channels:", ltostr(1) },
     { "ISDN device:", strdup(session->isdn_device_name) }
   };
-  int i;
+  unsigned int i;
 
   GtkWidget *window; /* the window itself, actually a GtkDialog */
   GtkWidget *table;  /* for tag->value pairs */
@@ -470,7 +470,10 @@ static void cb_about(GtkWidget *widget, gpointer data, guint action) {
 			"written for GNU/Linux and ISDN4Linux for\n"
 			"communicating via a full duplex soundcard (or\n"
 			"multiple sound devices if you like) and an\n"
-			"audio capable I4L ISDN device", GTK_JUSTIFY_CENTER);
+			"audio capable I4L ISDN device\n\n"
+			"Contact:\n"
+			"Roland Stigge, stigge@epost.de\n"
+                        "http://www.antcom.de/", GTK_JUSTIFY_CENTER);
 
   gtk_widget_show(window);
 }
