@@ -567,6 +567,7 @@ void session_set_state(struct session_t *session, enum state_t state) {
       session_effect_stop(session);
     break;
   default:
+    ;
   }
 
   /* status line */
@@ -683,22 +684,22 @@ void gdk_handle_audio_input(gpointer data, gint fd,
 
   switch (session->state) {
   case STATE_READY: /* we are in command mode */
-    if (debug)
-      fprintf(stderr, "Warning: Got audio input in ready mode.\n");
+    if (debug > 1)
+      fprintf(stderr, "Warning: Got audio input in ready mode (ALSA?).\n");
     /* flush audio input */
     read(session->audio_fd_in,
 	 session->audio_inbuf, session->fragment_size_in);
     break;
   case STATE_DIALING:
-    if (debug)
-      fprintf(stderr, "Warning: Got audio input in dialing mode.\n");
+    if (debug > 1)
+      fprintf(stderr, "Warning: Got audio input in dialing mode (ALSA?).\n");
     /* flush audio input */
     read(session->audio_fd_in,
 	 session->audio_inbuf, session->fragment_size_in);
     break;
   case STATE_RINGING:
-    if (debug)
-      fprintf(stderr, "Warning: Got audio input in ringing mode.\n");
+    if (debug > 1)
+      fprintf(stderr, "Warning: Got audio input in ringing mode (ALSA?).\n");
     /* flush audio input */
     read(session->audio_fd_in,
 	 session->audio_inbuf, session->fragment_size_in);
