@@ -55,8 +55,8 @@ struct session_t {
   char *audio_device_name_out; /* allocated memory! */
   int audio_fd_in;        /* audio device file descriptors */
   int audio_fd_out;
-  int audio_speed_in;     /* sound device recording speed */
-  int audio_speed_out;    /* sound device playback speed */
+  unsigned int audio_speed_in;     /* sound device recording speed */
+  unsigned int audio_speed_out;    /* sound device playback speed */
   int fragment_size_in;   /* sound device buffer fragment sizes */
   int fragment_size_out;
   int *format_priorities; /* 0-terminated sorted list of preferenced formats */
@@ -103,7 +103,7 @@ struct session_t {
   GtkWidget *hang_up_label;  /* the label on the hang up button */
   GtkWidget *dial_number_box; /* the dial number combo box */
   GList *dial_number_history; /* the last called numbers */
-  int dial_number_history_maxlen; /* how many numbers to remember */
+  unsigned int dial_number_history_maxlen; /* how many numbers to remember */
   GtkWidget *status_bar; /* the status bar */
   gint phone_context_id; /* a context for the status bar */
 
