@@ -15,6 +15,7 @@
 #include <errno.h>
 #include <sys/soundcard.h>
 #include <stdlib.h>
+#include <string.h>
 
 #include "sound.h"
 
@@ -234,23 +235,6 @@ int open_audio_devices(char *in_audio_device_name,
   }
 }
 
-/*
- * Closes specified input/output file descriptors
- * returns 0 on success, -1 on error
- */
-int close_audio_devices(int audio_fd_in, int audio_fd_out) {
-  if (close(audio_fd_in)) {
-    perror("close audio device");
-    return -1;
-  }
-  if (audio_fd_in != audio_fd_out)
-    if (close(audio_fd_out)) {
-      perror("close audio device");
-      return -1;
-    }
-  return 0;
-}
-
 /*
  * stops audio playback and recording on specified file descriptors
  */
@@ -259,7 +243,6 @@ int audio_stop(int audio_fd_in, int audio_fd_out) {
    * closing and reopening the devices (-> close/open_audio_devices).
    * Here, we flush the input buffer and use SNDCTL_DSP_RESET
    * to clean up for further recording, but on restart, old input comes again.
-   * So this function is included just for historical reasons ;)
    */
   int result;
   int frag_size;
@@ -302,6 +285,25 @@ int audio_stop(int audio_fd_in, int audio_fd_out) {
   return result;
 }
 
+/*
+ * Closes specified input/output file descriptors
+ * returns 0 on success, -1 on error
+ */
+int close_audio_devices(int audio_fd_in, int audio_fd_out) {
+  audio_stop(audio_fd_in, audio_fd_out);
+
+  if (close(audio_fd_in)) {
+    perror("close audio device");
+    return -1;
+  }
+  if (audio_fd_in != audio_fd_out)
+    if (close(audio_fd_out)) {
+      perror("close audio device");
+      return -1;
+    }
+  return 0;
+}
+
 /*
  * returns number of bytes per sample for the specified
  * OSS format (e.g. AFMT_U8)
