@@ -7,9 +7,13 @@
  *
  */
 
+/* regular GNU system includes */
+#include <stdio.h>
+#include <stdlib.h>
 #include <sys/time.h>
 #include <time.h>
 
+/* own header files */
 #include "util.h"
 
 /* util.h will be included everywhere needed so the right place is here */
@@ -93,3 +97,42 @@ char *un_vanity(char *s) {
 
   return s;
 }
+
+/*
+ * returns a string representing the time difference between the
+ * specified times
+ *
+ * NOTE: caller has to free() the returned string itself.
+ */
+char *timediff_str(time_t time1, time_t time0) {
+  int duration;
+  char *buf;
+  int hours;
+  int minutes;
+  int seconds;
+  
+  buf = (char *)malloc(9);
+
+  duration = (int)difftime(time1, time0);
+  seconds = duration % 60;
+  minutes = (duration / 60) % 60;
+  hours = duration / (60 * 60);
+  if (snprintf(buf, 9, "%02d:%02d:%02d", hours, minutes, seconds) >= 9)
+    buf[8] = '\0';
+
+  return buf;
+}
+
+/*
+ * returns a string with the specified long int as content
+ *
+ * NOTE: caller has to free() the returned memory
+ */
+char *ltostr(long int i) {
+  char *s;
+
+  if (asprintf(&s, "%ld", i) < 0)
+    return NULL;
+
+  return s;
+}
