@@ -10,6 +10,10 @@
 #ifndef _ANT_UTIL_H
 #define _ANT_UTIL_H
 
+/* regular GNU system includes */
+#include <sys/time.h>
+#include <time.h>
+
 #define SHORT_INTERVAL 10000
 /* 10 milliseconds */
 
@@ -20,5 +24,7 @@ int timeval_subtract (struct timeval *result,
 		      struct timeval *y);
 void ant_sleep(int usecs);
 char *un_vanity(char *s);
+char *timediff_str(time_t time1, time_t time0);
+char *ltostr(long int i);
 
 #endif /* util.h */
